define('aim/admin/view/ConfigFormView',['aim/util/Utils',
                                        'aim/admin/model/QueryCapacityLogModel',
                                        'aim/admin/model/QueryAbsenceLogModel',
                                        'aim/admin/model/QueryAssignmentLogModel',
                                        'aim/admin/view/ExportCapacityLogView',
                                        'aim/admin/view/ExportAbsenceLogView',
                                        'aim/admin/view/ExportAssignmentLogView'], 
                                        function(Utils,
                                        		QueryCapacityLogModel,
                                        		QueryAbsenceLogModel,
                                        		QueryAssignmentLogModel,
                                        		ExportCapacityLogView,
                                        		ExportAbsenceLogView,
                                        		ExportAssignmentLogView) {
	var ConfigFormView = Backbone.View.extend({
		
		el: '#adminForm',
		
		events: {
			"change #monday" : "mondayValueChanged",
			"change #tuesday" : "tuesdayValueChanged",
			"change #wednesday" : "wednesdayValueChanged",
			"change #thursday" : "thursdayValueChanged",
			"change #friday" : "fridayValueChanged",
			"change #saturday" : "saturdayValueChanged",
			"change #sunday" : "sundayValueChanged",
			"change #weeks-to-display" : "weeksToDisplayChanged",
			"change #display-mode" : "displayModeChanged",
			"change #color-fine" : "colorFineChanged",
			"change #color-light" : "colorLightChanged",
			"change #color-middle" : "colorMiddleChanged",
			"change #color-bad" : "colorBadChanged",
			"change #threshold-1" : "threshold1Changed",
			"change #threshold-2" : "threshold2Changed",
			"change #threshold-3" : "threshold3Changed",
			"click #admin-form-save-button" : "saveConfigValues",
			"click #capa-log" : "showCapacityExportDialog",
			"click #absence-log" : "showAbsenceExportDialog",
			"click #assignment-log" : "showAssignmentExportDialog"
		},

		initialize : function() {
			this.model.fetch();
			this.listenTo(this.model, 'sync', this.render);
			this.fieldsInError = new Array();
		},
		
		render : function() {
			AJS.$("#monday").attr("value", this.model.get('mondayValue'));
			AJS.$("#tuesday").attr("value", this.model.get('tuesdayValue'));
			AJS.$("#wednesday").attr("value", this.model.get('wednesdayValue'));
			AJS.$("#thursday").attr("value", this.model.get('thursdayValue'));
			AJS.$("#friday").attr("value", this.model.get('fridayValue'));
			AJS.$("#saturday").attr("value", this.model.get('saturdayValue'));
			AJS.$("#sunday").attr("value", this.model.get('sundayValue'));
			AJS.$("#weeks-to-display").attr("value", this.model.get('weeksToDisplay'));
			AJS.$("#display-mode").attr("value", this.model.get('displayMode'));
			AJS.$("#color-fine").attr("value", this.model.get('colorFine'));
			AJS.$("#color-fine").attr("style", "background-color: "+this.model.get('colorFine'));
			AJS.$("#color-light").attr("value", this.model.get('colorLight'));
			AJS.$("#color-light").attr("style", "background-color: "+this.model.get('colorLight'));
			AJS.$("#color-middle").attr("value", this.model.get('colorMiddle'));
			AJS.$("#color-middle").attr("style", "background-color: "+this.model.get('colorMiddle'));
			AJS.$("#color-bad").attr("value", this.model.get('colorBad'));
			AJS.$("#color-bad").attr("style", "background-color: "+this.model.get('colorBad'));
			AJS.$("#threshold-1").attr("value", this.model.get('threshold1'));
			AJS.$("#threshold-2").attr("value", this.model.get('threshold2'));
			AJS.$("#threshold-3").attr("value", this.model.get('threshold3'));
			if( ! this.model.attributes.errorMessage && ! this.model.attributes.warnMessage && ! this.model.attributes.infoMessage && this.fieldsInError.length == 0){
				Utils.clearMessageBar('#add-dialog-message-bar');
			}
			return this;	
		},
		
		showCapacityExportDialog : function(){
			if( ! this.exportCapacityLogView)
				this.exportCapacityLogView = new ExportCapacityLogView();
			this.exportCapacityLogView.queryCapacityLogModel = new QueryCapacityLogModel();
			this.exportCapacityLogView.render();
			AJS.dialog2("#export-capacity-dialog").show();
		},
		
		showAbsenceExportDialog : function(){
			if( ! this.exportAbsenceLogView)
				this.exportAbsenceLogView = new ExportAbsenceLogView();
			this.exportAbsenceLogView.queryAbsenceLogModel = new QueryAbsenceLogModel();
			this.exportAbsenceLogView.render();
			AJS.dialog2("#export-absence-dialog").show();
		},
		
		showAssignmentExportDialog : function(){
			if( ! this.exportAssignmentLogView)
				this.exportAssignmentLogView = new ExportAssignmentLogView();
			this.exportAssignmentLogView.queryAssignmentLogModel = new QueryAssignmentLogModel();
			this.exportAssignmentLogView.render();
			AJS.dialog2("#export-assignment-dialog").show();
		},
		
		saveConfigValues : function() {
			this.model.set('operation', "save");
			this.model.save(null, {success:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.admin.board.message.saved.value.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.admin.board.message.saved.value.message");
				var flag = Utils.sendMessage('success',title,'auto',text);
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.admin.board.message.error.value.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.admin.board.message.error.value.message");
				Utils.sendMessage('error',title,'manual',text);
			}});	
			return false;
		},

		mondayValueChanged : function(event) {
			this.model.set('mondayValue', event.currentTarget.value);
			this.model.set('operation', "save");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		tuesdayValueChanged : function(event) {
			this.model.set('tuesdayValue', event.currentTarget.value);
			this.model.set('operation', "tuesdayValueChanged");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		wednesdayValueChanged : function(event) {
			this.model.set('wednesdayValue', event.currentTarget.value);
			this.model.set('operation', "wednesdayValueChanged");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		thursdayValueChanged : function(event) {
			this.model.set('thursdayValue', event.currentTarget.value);
			this.model.set('operation', "thursdayValueChanged");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		fridayValueChanged : function(event) {
			this.model.set('fridayValue', event.currentTarget.value);
			this.model.set('operation', "fridayValueChanged");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		saturdayValueChanged : function(event) {
			this.model.set('saturdayValue', event.currentTarget.value);
			this.model.set('operation', "saturdayValueChanged");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		sundayValueChanged : function(event) {
			this.model.set('sundayValue', event.currentTarget.value);
			this.model.set('operation', "sundayValueChanged");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		weeksToDisplayChanged : function(event) {
			this.model.set('weeksToDisplay', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "weeksToDisplayChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		colorFineChanged : function(event) {
			this.model.set('colorFine', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "colorOneChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.board.message.validate.request.error");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		colorLightChanged : function(event) {
			this.model.set('colorLight', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "colorTwoChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		colorMiddleChanged : function(event) {
			this.model.set('colorMiddle', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "colorThreeChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.board.message.validate.request.error");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		colorBadChanged : function(event) {
			this.model.set('colorBad', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "colorFourChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.board.message.validate.request.error");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		threshold1Changed : function(event) {
			this.model.set('threshold1', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "thresholdOneChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.request.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		threshold2Changed : function(event) {
			this.model.set('threshold2', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "thresholdTwoChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		threshold3Changed : function(event) {
			this.model.set('threshold3', event.currentTarget.value);
			var fieldHolder = this.fieldsInError;
			this.model.set('operation', "thresholdThreeChanged");
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		displayModeChanged : function(event) {
			this.model.set('displayMode', event.currentTarget.value);
		}

	});
	return ConfigFormView;
});