define('aim/capacity/view/CapacityValueView',['aim/util/Utils',
                                     'aim/capacity/view/SelectResourceView',
                                     'aim/capacity/view/SelectFromView',
                                     'aim/capacity/view/SelectToView',
                                     'aim/capacity/view/ExtendFilterView'], function(
                                    		 Utils,
                                    		 SelectResourceView,
                                    		 SelectFromView,
                                    		 SelectToView,
                                    		 ExtendFilterView) {
	var CapacityValueView = Backbone.View.extend({
		
		el : '#add-capacity-dialog',
		
		events: {
			"change #resource-single-select" : "resourceSelectChanged",
			"click  #resource-single-select" : "resourceSelectSelected",
			"change #fromDate" : "fromChanged",
			"change #toDate" : "toChanged",
			"change #monday" : "mondayValueChanged",
			"change #tuesday" : "tuesdayValueChanged",
			"change #wednesday" : "wednesdayValueChanged",
			"change #thursday" : "thursdayValueChanged",
			"change #friday" : "fridayValueChanged",
			"change #saturday" : "saturdayValueChanged",
			"change #sunday" : "sundayValueChanged",
			"click #capacityvalues-save-button" : "saveCapacityValues",
			"click #capacityvalues-cancel-button" : "cancelCapacityValues"
		},
		
		initialize : function() {
			this.listenTo(this.model, 'sync', this.render);
			var selectResourceView = new SelectResourceView({model: this.model});
			var selectedFromDate = new SelectFromView({model: this.model});
			var selectedToDate = new SelectToView({model: this.model});
			var extendFilterView = new ExtendFilterView({model: this.model});
			this.fieldsInError = new Array();
		},
		
		render : function() {
			var capacityModel = this.model;
			AJS.$("#monday").attr("value", capacityModel.get('mondayValue'));
			AJS.$("#tuesday").attr("value", capacityModel.get('tuesdayValue'));
			AJS.$("#wednesday").attr("value", capacityModel.get('wednesdayValue'));
			AJS.$("#thursday").attr("value", capacityModel.get('thursdayValue'));
			AJS.$("#friday").attr("value", capacityModel.get('fridayValue'));
			AJS.$("#saturday").attr("value", capacityModel.get('saturdayValue'));
			AJS.$("#sunday").attr("value", capacityModel.get('sundayValue'));
			if( ! this.model.attributes.errorMessage && ! this.model.attributes.warnMessage && ! this.model.attributes.infoMessage){
				Utils.clearMessageBar('#add-dialog-message-bar');
				Utils.clearFieldMarker(this.fieldsInError);
			}
			return this;		
		},
		
		saveCapacityValues : function() {
			if(this.model.get('selectedResource') == 0 || this.model.attributes.errorMessage)
				return this;
			var that = this;
			var capacityModel = this.model;
			capacityModel.set('operation', "spreadInPeriod");
			capacityModel.set('saved', "true");
			capacityModel.save(null, {success:function(model, res, options) {
				that.options.contextModel.set('operation','refresh');
				that.options.contextModel.save();
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.saved.value.title");
				var replacements = {'%USER%': model.attributes.changedResource.displayName, '%FROM%': model.attributes.from,'%TO%': model.attributes.to };
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.saved.value.message");
				var message = Utils.replace(replacements,text);
				var flag = Utils.sendMessage('success',title,'auto',message);
				Utils.validateFlagModel(model,'naomi.templates.js.jirarp.board.message');
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.error.value.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.error.value.message");
				Utils.sendMessage('error',title,'manual',text);
			}});	
			AJS.dialog2("#add-capacity-dialog").hide();
		},

		cancelCapacityValues : function() {
			AJS.dialog2("#add-capacity-dialog").hide();
		},
		
		fromChanged : function(event) {
			var capacityValueModel = this.model;
			var value = event.currentTarget.value;
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			capacityValueModel.set('from', value);
			capacityValueModel.set('selectedFromChanged', "true");
			capacityValueModel.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.error.from.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.error.from.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},
		
		toChanged : function(event) {
			var capacityValueModel = this.model;
			var value = event.currentTarget.value;
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			capacityValueModel.set('to', value);
			capacityValueModel.set('selectedToChanged', "true");
			capacityValueModel.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.error.to.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.error.to.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);

			}});
		},
		
		mondayValueChanged : function(event) {
			this.model.set('mondayValue', event.currentTarget.value);
			this.model.set('operation', "validateCapacityValue");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		tuesdayValueChanged : function(event) {
			this.model.set('tuesdayValue', event.currentTarget.value);
			this.model.set('operation', "validateCapacityValue");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
					Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
				},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		wednesdayValueChanged : function(event) {
			this.model.set('wednesdayValue', event.currentTarget.value);
			this.model.set('operation', "validateCapacityValue");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		thursdayValueChanged : function(event) {
			this.model.set('thursdayValue', event.currentTarget.value);
			this.model.set('operation', "validateCapacityValue");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});

		},

		fridayValueChanged : function(event) {
			this.model.set('fridayValue', event.currentTarget.value);
			this.model.set('operation', "validateCapacityValue");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});

		},

		saturdayValueChanged : function(event) {
			this.model.set('saturdayValue', event.currentTarget.value);
			this.model.set('operation', "validateCapacityValue");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		sundayValueChanged : function(event) {
			this.model.set('sundayValue', event.currentTarget.value);			
			this.model.set('operation', "validateCapacityValue");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar','#sunday', fieldHolder);
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.message.validate.no.number.format");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		resourceSelectSelected : function(event) {
			var options = event.currentTarget.selectedOptions;
			AJS.$('#resource-single-select').focus();
		},

		resourceSelectChanged : function(event) {
			var value = event.currentTarget.value;
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.set('selectedResource', value);	
			this.model.set('operation', "validateCapacityValue");
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar');

			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.capacity.board.add.dialog.message.error.resource.change.title");
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, title, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		}
	});

	return CapacityValueView;
});